#
# spec file for package python-emcee
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# NEP 29: python36-numpy and -scipy are no longer available in TW
%define         skip_python36 1
Name:           python-emcee
Version:        3.1.4
Release:        1.5
Summary:        Python affine-invariant ensemble MCMC sampling
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/dfm/emcee
Source:         https://files.pythonhosted.org/packages/source/e/emcee/emcee-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-h5py
Requires:       python-numpy
Requires:       python-scipy
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module h5py}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
# /SECTION
%python_subpackages

%description
Emcee is a  Python implementation of the affine-invariant
ensemble sampler for Markov chain Monte Carlo (MCMC)
proposed by Goodman & Weare (2010)

http://cims.nyu.edu/~weare/papers/d13.pdf

%prep
%setup -q -n emcee-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc AUTHORS.rst README.rst
%{python_sitelib}/emcee
%{python_sitelib}/emcee-%{version}-py*.egg-info

%changelog
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.4:
  * Handling updated kstest interface in scipy 1.10
* Wed Sep 28 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * be more specific in %%file section
- update to version 3.1.3:
  * Pass on random generator to KDE resample method
  * seed longdouble test
* Sun May 29 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.1.2:
  - Make the sample state indexable [gh#dfm/emcee#425].
  - Remove NumPy from SETUP_REQUIRES [gh#dfm/emcee#427].
* Sat Sep 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.1.1:
  * Added support for a progress bar description
    (gh#dfm/emcee#401).
* Sat Jul  3 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.1.0:
  * Added preliminary support for named parameters
    (gh#dfm/emcee#386).
  * Improved handling of blob dtypes (gh#dfm/emcee#363).
  * Fixed various small bugs and documentation issues
- New BuildRequires: python-pip, python-wheel, and
  python-setuptool_scm.
* Fri Feb 12 2021 Benjamin Greiner <code@bnavigator.de>
- NEP 29: python36-numpy and -scipy are no longer available in TW
  skip python36 build
* Sun Aug  9 2020 John Vandenberg <jayvdb@gmail.com>
- Tidy spec
* Sat Aug  1 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.2:
  * Added tutorial for moves interface
  * Added information about contributions to documentation
  * Improved documentation for installation and testing
  * Fixed dtype issues and instability in linear dependence test
- Changes from version 3.0.1:
  * Added support for long double dtypes
  * Improved packaging and release infrastructure
  * Fixed bug in initial linear dependence test
- Changes from version 3.0.2:
  * Added progress bars using `tqdm
    <https://github.com/tqdm/tqdm>`_.
  * Added HDF5 backend using `h5py <http://www.h5py.org/>`_.
  * Added new ``Move`` interface for more flexible specification
    of proposals.
  * Improved autocorrelation time estimation algorithm.
  * Switched documentation to using Jupyter notebooks for
    tutorials.
  * More details can be found `on the docs
    <https://emcee.readthedocs.io/en/v3.0.0/user/upgrade/>`_.
- Add Requires: python-scipy, python-h5py.
- Implement %%check section to run tests; needs BuildRequires:
  python-numpy, python-scipy, python-h5py, and python-pytest.
* Thu Mar 22 2018 toddrme2178@gmail.com
- Initial version
